@@ -21,3 +21,17 @@ dichot <- function(data, out='numeric') {
   if(out=='factor') for(i in 1:ncol(res)) res[,i] <- as.factor(res[,i])
   return(res)
 }
+
+
+test.values <- function(x, y, weights = NULL) {
+  if(is.null(weights)) weights <- rep(1, length(x))
+  ww <- length(weights)*weights/sum(weights)
+  N <- length(x)
+  moyennes <- sapply(split(data.frame(y,ww), x), function(x) weighted.mean(x[,1],x[,2]))
+  effectifs <- as.numeric(weighted.table(x, weights = ww))
+  moy <- weighted.mean(y, ww)
+  dev <- weighted.sd(y, ww)
+  deviations <- sqrt(sapply(effectifs, function(x) (N-x)/(N-1)*dev*dev/x))
+  res <- (moyennes-moy)/deviations
+  return(res)
+}
